summaryrefslogtreecommitdiffstats
path: root/ksirc/kstextview.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /ksirc/kstextview.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'ksirc/kstextview.h')
-rw-r--r--ksirc/kstextview.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/ksirc/kstextview.h b/ksirc/kstextview.h
index 1c537e95..6b3813a8 100644
--- a/ksirc/kstextview.h
+++ b/ksirc/kstextview.h
@@ -40,7 +40,7 @@ struct StringPtr
StringPtr( const TQChar *_ptr, uint _len )
: ptr( _ptr ), len( _len ) {}
explicit StringPtr( const TQString &s ) // use with care!
- : ptr( s.unicode() ), len( s.length() ) {}
+ : ptr( s.tqunicode() ), len( s.length() ) {}
inline bool isNull() const { return ptr == 0; }
@@ -142,8 +142,8 @@ class SelectionPoint;
class Item
{
public:
- enum LayoutResetStatus { DeleteItem, KeepItem };
- enum SelectionStatus { SelectionStart = 0, InSelection, SelectionEnd, SelectionBoth,
+ enum LayoutResettqStatus { DeleteItem, KeepItem };
+ enum SelectiontqStatus { SelectionStart = 0, InSelection, SelectionEnd, SelectionBoth,
NoSelection };
enum SelectionAccuracy { SelectExact, SelectFuzzy };
@@ -163,13 +163,13 @@ public:
virtual Item *breakLine( int width );
- virtual LayoutResetStatus resetLayout() = 0;
+ virtual LayoutResettqStatus resetLayout() = 0;
virtual int calcSelectionOffset( int x );
- void setSelectionStatus( SelectionStatus status ) { m_selection = status; }
+ void setSelectiontqStatus( SelectiontqStatus status ) { m_selection = status; }
- SelectionStatus selectionStatus() const { return m_selection; }
+ SelectiontqStatus selectiontqStatus() const { return m_selection; }
void selectionOffsets( int &startOffset, int &endOffset );
@@ -194,7 +194,7 @@ protected:
virtual void calcExtends() const = 0;
- SelectionStatus m_selection;
+ SelectiontqStatus m_selection;
TextLine *m_line;
TextParag *m_parag;
ItemProperties m_props;
@@ -211,7 +211,7 @@ public:
virtual Item *breakLine( int width );
- virtual LayoutResetStatus resetLayout();
+ virtual LayoutResettqStatus resetLayout();
virtual int calcSelectionOffset( int x );
@@ -247,7 +247,7 @@ public:
virtual void paint( TQPainter &painter );
- virtual LayoutResetStatus resetLayout();
+ virtual LayoutResettqStatus resetLayout();
protected:
virtual void calcExtends() const;
@@ -354,7 +354,7 @@ public:
~TextParag();
- void layout( int width );
+ void tqlayout( int width );
void paint( TQPainter &p, int y, int maxY );
@@ -482,7 +482,7 @@ public:
bool removeParag( const TextParagIterator &parag );
- void clearSelection( bool repaint = false ); // ### re-consider the repaint arg...
+ void clearSelection( bool tqrepaint = false ); // ### re-consider the tqrepaint arg...
TQString selectedText() const { return m_selectedText; }
@@ -537,7 +537,7 @@ private:
SelectionPoint *selectionStart();
SelectionPoint *selectionEnd();
- void layout( bool force = true );
+ void tqlayout( bool force = true );
Item *itemAt( const TQPoint &pos, SelectionPoint *selectionInfo = 0,
Item::SelectionAccuracy accuracy = Item::SelectExact );